@@ -1,30 +1,23 @@
 # -*- python -*-
-# -*- coding: utf-8 -*-
 #
-#  This file is part of the CNO software
+#  This file is part of the cnolab package
 #
-#  Copyright (c) 2011-2012 - EBI
+#  Copyright (c) 2011-2012 - EBI - EMBL
 #
-#  File author(s): Thomas Cokelaer <cokelaer@ebi.ac.uk>
+#  File author(s): Thomas Cokelaer (cokelaer@ebi.ac.uk)
 #
-#  Distributed under the GPLv2 License.
+#  Distributed under the GPL License.
 #  See accompanying file LICENSE.txt or copy at
-#      http://www.gnu.org/licenses/gpl-2.0.html
+#      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  CNO website: http://www.ebi.ac.uk/saezrodriguez/software.html
+#  ModelData website: http://www.ebi.ac.uk/~cokelaer/cnolab
 #
 ##############################################################################
 # $Id: tools.py 2193 2012-08-22 21:39:17Z cokelaer $
 """Utilities for cnolab.wrapper
 
-Created by Thomas Cokelaer <cokelaer@ebi.ac.uk>
-Copyright (c) 2011. GPL
-
-.. testsetup:: *
-
-    from rpy2.robjects.packages import importr
-    import numpy
-    from cno import *
+:author: Thomas Cokelaer <cokelaer@ebi.ac.uk>
+:license: Copyright (c) 2012. GPL
 
 """
 __author__ = """\n""".join(['Thomas Cokelaer <cokelaer@ebi.ac.uk'])
@@ -57,20 +50,39 @@ or if it is available on BioConductor, type:
 class RPackage(object):
     """simple class to import a R package and get metainfo
 
-    from rtools.package import RPackage
-    r = RPackage("CellNOptR")
-    r.version()
-    r.load()
+    ::
+
+        from rtools.package import RPackage
+        r = RPackage("CellNOptR")
+        r.version
+        r.package
 
     # no error returned but only info and error based on logging module.
     """
     def __init__(self, name, require="0.0"):
+        """
+
+        :param str name: name of a R package installed on your system
+        :param str require: the minimal version required. Use valid string
+            format such as "1.0.0" or "1.0" 
+        """
         self.name = name
         self.package = None
         self.require = require
         self.load()
 
     def load(self):
+        """Load the package.
+
+        First, try to load the package. If unsuccessful, return an error 
+        RRuntimeError. If successful, check that the version required is large
+        enough. If not, return an error with the logging module. The reason for
+        not returning an error is that several packages may need to be imported, some of
+        them are optional. So, we do not want an error.
+
+        The level of error/verbosity is also related to your logging setup. 
+
+        """
         Rwarning(False)
         try:
             package = importr(self.name)
