@@ -331,6 +331,14 @@ class RConvertor(object):
         """
         if data == None:
             return robjects.NULL
+
+        elif isinstance(data, dict):
+            newd = {}
+            for k, v in data.iteritems():
+                rc = RConvertor()
+                newd[k] = rc.convert(v)
+            return rpy2.robjects.ListVector(newd)
+
         elif isinstance(data, list):
             t = type(data[0])
             if forcetype != None:
